@@ -130,7 +130,7 @@ void clean_up_molecules_info (gboolean usel)
     combo_mol[i] = destroy_this_widget (combo_mol[i]);
     combo_mol[i] = create_combo_mol (i);
     add_box_child_start (GTK_ORIENTATION_HORIZONTAL, mol_box[i], combo_mol[i], FALSE, FALSE, 10);
-    gtk_widget_show (combo_mol[i]);
+    show_the_widgets (combo_mol[i]);
     changed_mol_box (GTK_COMBO_BOX(combo_mol[i]), GINT_TO_POINTER(i+1));
   }
   set_mol_num_label ();
@@ -464,7 +464,7 @@ G_MODULE_EXPORT void run_add_molecule_to_field (GtkDialog * dialog, gint respons
   \brief add molecule to force field - creating the dialog
 
   \param action the GAction sending the signal
-  \param parameter GVariant parameter of the GAction
+  \param parameter GVariant parameter of the GAction, if any
   \param data the associated data pointer
 */
 G_MODULE_EXPORT void add_molecule_to_field (GSimpleAction * action, GVariant * parameter, gpointer data)
@@ -746,7 +746,7 @@ G_MODULE_EXPORT void run_remove_molecule_from_field (GtkDialog * rmol, gint resp
   \brief remove molecule from force field - creating the dialog
 
   \param action the GAction sending the signal
-  \param parameter GVariant parameter of the GAction
+  \param parameter GVariant parameter of the GAction, if any
   \param data the associated data pointer
 */
 G_MODULE_EXPORT void remove_molecule_from_field (GSimpleAction * action, GVariant * parameter, gpointer data)
