@@ -103,7 +103,7 @@ GtkWidget * calc_window (int i)
 #ifndef GTK4
   /* GtkWidget * apply_button =
   button_set_image (GTK_BUTTON(apply_button), calc_name[i], IMG_FILE, (gpointer)calc_img[i]);
-  gtk_widget_show (apply_button); */
+  show_the_widgets (apply_button); */
 #endif
   return calc_dialog;
 }
@@ -120,7 +120,7 @@ G_MODULE_EXPORT void set_max (GtkEntry * entry, gpointer data)
 {
   int c = GPOINTER_TO_INT(data);
   const gchar * m = entry_get_text (entry);
-  double v = atof(m);
+  double v = string_to_double ((gpointer)m);
   if (v > 0)
   {
     if (active_project -> max[c] != v)
@@ -146,7 +146,7 @@ G_MODULE_EXPORT void set_delta (GtkEntry * entry, gpointer data)
 {
   int c = GPOINTER_TO_INT(data);
   const gchar * m = entry_get_text (entry);
-  double v = atof(m);
+  double v = string_to_double ((gpointer)m);
   int i, j, k;
   i = (int)v;
   if (c == RI)
@@ -300,7 +300,7 @@ void calc_msd (GtkWidget * vbox)
 G_MODULE_EXPORT void set_numa (GtkEntry * entry, gpointer data)
 {
   const gchar * m = entry_get_text (entry);
-  double v = atof(m);
+  double v = string_to_double ((gpointer)m);
   int i, j;
   i = (int)v;
   if (i > 0)
@@ -929,23 +929,23 @@ G_MODULE_EXPORT void expand_opt (GtkWidget * exp, gpointer data)
   {
     if (i == 1)
     {
-      gtk_widget_hide (avbox);
+      hide_the_widgets (avbox);
     }
     else
     {
-      gtk_widget_hide (smbox);
+      hide_the_widgets (smbox);
     }
   }
   else
   {
     if (i == 1)
     {
-      gtk_widget_show (avbox);
+      show_the_widgets (avbox);
 
     }
     else
     {
-      gtk_widget_show (smbox);
+      show_the_widgets (smbox);
     }
   }
   gtk_widget_set_size_request (exp, -1, -1);
@@ -964,7 +964,7 @@ G_MODULE_EXPORT void set_advanced_sq (GtkEntry * entry, gpointer data)
 {
   int c = GPOINTER_TO_INT(data);
   const gchar * m = entry_get_text (entry);
-  double v = atof(m);
+  double v = string_to_double ((gpointer)m);
   if (v != active_project -> sk_advanced[c])
   {
     if (c == 0 && (v < 0.0 || v > 1.0))
@@ -996,7 +996,7 @@ G_MODULE_EXPORT void set_sfact (GtkEntry * entry, gpointer data)
   const gchar * m;
   int i = GPOINTER_TO_INT(data);
   m = entry_get_text (entry);
-  double v = atof(m);
+  double v = string_to_double ((gpointer)m);
   if (v <= 0.0 || v >= 1.0)
   {
     show_warning ("The smoothing factor must be between 0.0 and 1.0", calc_win);
@@ -1020,11 +1020,11 @@ G_MODULE_EXPORT void on_show_curve_toolbox (GtkWidget * widg, gpointer data)
 {
   if (! is_the_widget_visible (curvetoolbox))
   {
-    gtk_widget_show (curvetoolbox);
+    show_the_widgets (curvetoolbox);
   }
   else
   {
-    gtk_widget_hide (curvetoolbox);
+    hide_the_widgets (curvetoolbox);
   }
 }
 
@@ -1043,6 +1043,10 @@ G_MODULE_EXPORT void on_smoother_released (GtkButton * button, gpointer data)
   l = GPOINTER_TO_INT(data);
   if (active_project -> visok[l])
   {
+    if (l == 2)
+    {
+      xsk = duplicate_double(active_project -> curves[l][0] -> ndata, active_project -> curves[l][0] -> data[0]);
+    }
     i = 1;
     smooth_and_save_ (active_project -> curves[l][i-1] -> data[0],
                       active_project -> curves[l][i-1] -> data[1],
@@ -1157,8 +1161,13 @@ G_MODULE_EXPORT void on_smoother_released (GtkButton * button, gpointer data)
                           & l);
       }
     }
+    if (l == 2)
+    {
+      g_free (xsk);
+      xsk = NULL;
+    }
     fill_tool_model ();
-    gtk_widget_show (curvetoolbox);
+    show_the_widgets (curvetoolbox);
     if (l == 0 || l == 3)
     {
       for (i=0; i<4; i=i+3) update_after_calc (i);
@@ -1330,22 +1339,22 @@ G_MODULE_EXPORT void run_on_calc_activate (GtkDialog * dial, gint response_id, g
         case RI-1:
           if (test_rings ())
           {
-            //gtk_widget_show (spinner);
+            //show_the_widgets (spinner);
             //gtk_spinner_start (GTK_SPINNER(spinner));
             on_calc_rings_released (calc_win, NULL);
             toggled_rings = FALSE;
             //gtk_spinner_stop (GTK_SPINNER(spinner));
-            //gtk_widget_hide (spinner);
+            //hide_the_widgets (spinner);
           }
           break;
         case CH-1:
           if (test_rings ())
           {
-            //gtk_widget_show (spinner);
+            //show_the_widgets (spinner);
             //gtk_spinner_start (GTK_SPINNER(spinner));
             on_calc_chains_released (calc_win, NULL);
             //gtk_spinner_stop (GTK_SPINNER(spinner));
-            //gtk_widget_hide (spinner);
+            //hide_the_widgets (spinner);
           }
           break;
         case SP-1:
@@ -1417,6 +1426,6 @@ G_MODULE_EXPORT void on_calc_activate (GtkWidget * widg, gpointer data)
   /*GtkWidget * spinner = gtk_spinner_new ();
   add_box_child_start (GTK_ORIENTATION_VERTICAL, vbox, spinner, FALSE, FALSE, 0);
   gtk_widget_set_size_request (spinner, -1, 30);
-  gtk_widget_hide (spinner);*/
+  hide_the_widgets (spinner);*/
   run_this_gtk_dialog (calc_win, G_CALLBACK(run_on_calc_activate), data);
 }
