@@ -579,8 +579,7 @@ int check_opengl_rendering ()
   proc_name = "atomes_startup_testing";
   proc_path = g_build_filename (PACKAGE_LIBEXEC, proc_name, NULL);
 #endif
-  g_print ("proc_dir= %s\n", proc_dir);
-  g_print ("proc_path= %s\n", proc_path);
+
 #ifdef CODEBLOCKS
   GSubprocess * proc = g_subprocess_new (G_SUBPROCESS_FLAGS_NONE, & error, proc_path, NULL);
 #else
@@ -592,7 +591,7 @@ int check_opengl_rendering ()
   GSubprocess * proc = g_subprocess_new (G_SUBPROCESS_FLAGS_NONE, & error, proc_path, NULL);
 #endif
 #endif
-  g_print ("subprocess: %p\n", proc);
+
   if (error)
   {
     g_print ("error: %s\n", error -> message);
@@ -645,9 +644,6 @@ int main (int argc, char *argv[])
   gboolean RUNC = FALSE;
 
 #ifdef G_OS_WIN32
-#ifndef DEBUG
-  FreeConsole ();
-#endif
   PACKAGE_PREFIX = g_win32_get_package_installation_directory_of_module (NULL);
   // g_win32_get_package_installation_directory (NULL, NULL);
 #endif
@@ -798,6 +794,11 @@ int main (int argc, char *argv[])
 
   if (RUNC)
   {
+#ifdef G_OS_WIN32
+#ifndef DEBUG
+    FreeConsole ();
+#endif
+#endif
     atomes_visual = check_opengl_rendering ();
     if (atomes_visual == 1)
     {
