@@ -358,7 +358,7 @@ void shift_has_changed (gpointer data, double val)
 G_MODULE_EXPORT void set_shift (GtkEntry * res, gpointer data)
 {
   const gchar * m = entry_get_text (res);
-  double v = atof(m);
+  double v = string_to_double ((gpointer)m);
   shift_has_changed (data, v);
 }
 
